==> igniteui-react-charts-16.6.8.tgz: package/ES2015/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class RelativeStrengthIndexIndicator extends StrategyBasedIndicator {
    constructor() {
        super();
        this.pd = 1;
    }
    get_p5() {
        return new RelativeStrengthIndexIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return RelativeStrengthIndexIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get qq() {
        return typeGetValue(this.c(RelativeStrengthIndexIndicator.qr));
    }
    set qq(a) {
        this.h(RelativeStrengthIndexIndicator.qr, a);
    }
    qb() {
        return this.qq;
    }
    qk(a) {
        this.qq = a;
    }
}
RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
RelativeStrengthIndexIndicator.qr = StrategyBasedIndicator.qn(14, RelativeStrengthIndexIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class RelativeStrengthIndexIndicator extends StrategyBasedIndicator {
    constructor() {
        super();
        this.pk = 1;
    }
    get_qc() {
        return new RelativeStrengthIndexIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return RelativeStrengthIndexIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get qx() {
        return typeGetValue(this.c(RelativeStrengthIndexIndicator.qy));
    }
    set qx(a) {
        this.h(RelativeStrengthIndexIndicator.qy, a);
    }
    qi() {
        return this.qx;
    }
    qr(a) {
        this.qx = a;
    }
}
RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
RelativeStrengthIndexIndicator.qy = StrategyBasedIndicator.qu(14, RelativeStrengthIndexIndicator.$);
